diff test/runtime/RedefineObject/Agent.java @ 14909:4ca6dc0799b6

Backout jdk9 merge
author Gilles Duboscq <duboscq@ssw.jku.at>
date Tue, 01 Apr 2014 13:57:07 +0200
parents 4f0acb75c921
children 89152779163c
line wrap: on
line diff
--- a/test/runtime/RedefineObject/Agent.java	Tue Apr 01 14:09:03 2014 +0200
+++ b/test/runtime/RedefineObject/Agent.java	Tue Apr 01 13:57:07 2014 +0200
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2013, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -65,8 +65,8 @@
     public static void main(String[] args) {
         byte[] ba = new byte[0];
 
-        // If it survives 100 GC's, it's good.
-        for (int i = 0; i < 100 ; i++) {
+        // If it survives 1000 GC's, it's good.
+        for (int i = 0; i < 1000 ; i++) {
             System.gc();
             ba.clone();
         }